@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deduplicates named chunks emitted more than once',
 	options: {
 		// For the second entry, a facade is created
@@ -28,4 +28,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
