@@ -1,6 +1,6 @@
 const { assertIncludes } = require('../../../utils.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'errors on warnings with --failAfterWarnings',
 	command: 'rollup -i main.js --failAfterWarnings',
 	error: () => true,
@@ -8,4 +8,4 @@ module.exports = {
 		assertIncludes(stderr, '[!] Warnings occurred and --failAfterWarnings flag present');
 		return true;
 	}
-};
+});
