@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'watches without a config file',
 	command: 'rollup main.js --watch --format es --file _actual/main.js',
 	abortOnStderr(data) {
@@ -6,4 +6,4 @@ module.exports = {
 			return true;
 		}
 	}
-};
+});
