@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports optional chaining with namespace objects',
 	expectedWarnings: ['MISSING_EXPORT']
-};
+});
