@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'passing unbound default export to function cannot rebind it'
-};
+});
