@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'respects the order of entry points when there are additional facades for chunks',
 	options: {
 		input: {
@@ -9,6 +9,7 @@ module.exports = {
 			other: 'other'
 		},
 		plugins: {
+			name: 'test-plugin',
 			generateBundle(options, bundle) {
 				assert.deepStrictEqual(
 					Object.keys(bundle).map(id => [id, bundle[id].code]),
@@ -24,4 +25,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
