@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'checks side effects when reassigning namespace members',
 	options: {
 		treeshake: { tryCatchDeoptimization: false }
 	}
-};
+});
